## Schematic

RC circuit and RL circuit

RLC circuit

- The objective is to apply an AC voltage to a series RC, RL or RLC circuit to study the amplitude and phase across the circuit elements as a function of frequency.
- The reactance values of Capacitors and Inductors change with frequency.
- In the case of RLC circuit, resonance occurs When XL = Xc, and voltage across LC becomes early zero(not exactly zero because of the resistance of the Inductor
- Connect A3 to the junction of L and C to monitor the voltages across them. To observe series resonance, Choose C = 1uF and L = 10 mH. The frequency to around 1600 Hz, adjust frequency to make the phase difference across LC almost to zero.